package com.persagy.account.controller;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.google.common.collect.Lists;
import com.persagy.common.utils.ResponseResult;
import com.persagy.common.utils.ResponseResultUtil;
import com.persagy.account.pojo.dto.SaasProduct;
import com.persagy.account.pojo.dto.SaasProduct.Builder;
import com.persagy.account.service.ISaasProductService;

import cn.hutool.core.collection.CollectionUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * 产品信息
 * 
 * @version 1.0.0
 * @company persagy 
 * @author zhangqiankun
 * @date 2021-04-26 15:45:41
 */

@Api(tags = "产品信息")
@RestController
@RequestMapping(value = "/saasProduct", method = RequestMethod.POST)
public class SaasProductController {
    @Autowired
    private ISaasProductService saasProductService;
    
    /**
     * 列表查询
     */
    @ApiOperation(value = "列表查询")
    @RequestMapping(value = "querySaasProductList")
    public ResponseResult querySaasProductList(@RequestBody SaasProduct saasProduct) {
    	Builder builder = new SaasProduct.Builder().createQueryWrapper();
    	LambdaQueryWrapper<SaasProduct> queryWrapper = builder.builderQueryWrapper();
    	List<SaasProduct> list = this.saasProductService.list(queryWrapper);
    	if (CollectionUtil.isEmpty(list)) {
			return ResponseResultUtil.successResult(Lists.newArrayList(), 0L);
		}
        return ResponseResultUtil.successResult(list, (long)list.size());
    }

    /**
     * 新增
     */
	@ApiOperation(value = "保存")
	@RequestMapping(value = "createSaasProduct")
    public ResponseResult createSaasProduct(@RequestBody SaasProduct saasProduct) {
        boolean result = this.saasProductService.save(saasProduct);
        return result ? ResponseResultUtil.successResult("保存成功") : ResponseResultUtil.errorResult("保存失败");
    }
    
    /**
     * 更新
     */
	@ApiOperation(value = "更新")
	@RequestMapping(value = "updateSaasProduct")
    public ResponseResult updateSaasProduct(@RequestBody SaasProduct saasProduct) {
        boolean result = this.saasProductService.updateById(saasProduct);
        return result ? ResponseResultUtil.successResult("更新成功") : ResponseResultUtil.errorResult("更新失败");
    }

    /**
     * 物理删除
     */
    @ApiOperation(value = "删除")
    @RequestMapping(value = "deleteSaasProduct")
    public ResponseResult deleteSaasProduct(@RequestBody SaasProduct saasProduct) {
        boolean result = this.saasProductService.removeById(saasProduct.getId());
        return result ? ResponseResultUtil.successResult("删除成功") : ResponseResultUtil.errorResult("删除失败");
    }
    
}
